function webrtc(){}

webrtc.prototype.getStream = function(option){
	let constraints = {
		audio : option.audio,
		video : option.video
	}
	if(option.media == 'screen'){
		navigator.mediaDevices.getDisplayMedia(constraints)
		.then(function(stream){
			option.success(stream);
		});
	}
	if(option.media == 'webcam'){
		navigator.mediaDevices.getUserMedia(constraints)
		.then(function(stream){
			option.success(stream);
		});
	}
}

webrtc.prototype.attachStream = function(option){
	option.target.srcObject = option.stream;
	option.target.play();
}

webrtc.prototype.stopStream = function(stream){
	stream.getTracks().forEach(function(track) { track.stop(); });
}

webrtc.prototype.capture = function(){
	let self = this;
	function openCamera(media){
		self.getStream({
			audio : false,
			video : true,
			media : media,
			success : function(stream){
				self.videoElementToCapture = document.createElement('video');
				self.streamToCloseCamera = stream;
				self.videoElementToCapture.srcObject = stream;
				self.videoElementToCapture.play();
			}
		});
	}
	function takeCapture(media,videoElement,callback){
		if(videoElement.videoWidth != 0 && videoElement.videoHeight != 0){
			let canvas = document.createElement('canvas');
			let context = canvas.getContext('2d');
	      	canvas.width = videoElement.videoWidth;
	      	canvas.height = videoElement.videoHeight;
	      	context.drawImage(videoElement, 0, 0, videoElement.videoWidth, videoElement.videoHeight);
		    callback({
		    	src : canvas.toDataURL('image/png'),
		    	width : videoElement.videoWidth,
		    	height : videoElement.videoHeight
		    });
		    return;
		}
	}
	return {
		screen : {
			openCamera : function(){
				openCamera('screen');
			},
			take : function(callback){
				takeCapture('screen',self.videoElementToCapture,function(data){
					callback(data);
				});
			}
		},
		webcam : {
			openCamera : function(){
				openCamera('webcam');
			},
			take : function(callback){
				takeCapture('webcam',self.videoElementToCapture,function(data){
					callback(data);
				});
			}
		},
		close : function(){
			self.stopStream(self.streamToCloseCamera);
			delete self.videoElementToCapture;
		}
	}
}

webrtc.prototype.recorder = {
	options : null,
	mediaRecorder : null,
	chunks : [],
	init : function(app){
		let self = this;
		app.getStream({
			audio : self.options.audio,
			video : self.options.video,
			media : self.options.media,
			success : function(stream){
				self.mediaRecorder = new MediaRecorder(stream);
				self.mediaRecorder.ondataavailable = function(event){
					if (event.data.size > 0) {
					    self.chunks.push(event.data);
					}
				}
			}
		});
	},
	start : function(){
		let self = this;
		self.mediaRecorder.start();
	},
	stop : function(){
		let self = this;
		self.mediaRecorder.stop();
	},
	getSrc : function(){
		let self = this;
		return URL.createObjectURL(new Blob(self.chunks, {
			type: `video/${self.options.type}`
		}));
	},
	download : function(){
		let self = this;
		let url = self.getSrc();
		let a = document.createElement('a');
	  	document.body.appendChild(a);
	  	a.style = 'display: none';
	  	a.href = url;
	  	a.download = `recoder.${self.options.type}`;
	  	a.click();
	  	a.remove();
	  	window.URL.revokeObjectURL(url);
	}
}